summaryrefslogtreecommitdiff
path: root/test/rubygems/test_gem_update_suggestion.rb
diff options
context:
space:
mode:
authorJosef Šimánek <josef.simanek@gmail.com>2023-09-30 12:00:36 +0200
committerHiroshi SHIBATA <hsbt@ruby-lang.org>2023-10-03 16:13:18 +0900
commit0046c67dd8d56960de6579ba05cac622412c6d54 (patch)
tree0e0bc8db48d5bcb0076b8898af94422e044f4f3f /test/rubygems/test_gem_update_suggestion.rb
parent798083fac807ff2c510f1072685f6b33e229b436 (diff)
[rubygems/rubygems] Fix typo: eglible -> eligible.
https://github.com/rubygems/rubygems/commit/1e487e1337
Diffstat (limited to 'test/rubygems/test_gem_update_suggestion.rb')
-rw-r--r--test/rubygems/test_gem_update_suggestion.rb96
1 files changed, 48 insertions, 48 deletions
diff --git a/test/rubygems/test_gem_update_suggestion.rb b/test/rubygems/test_gem_update_suggestion.rb
index 2f9221ec2f..8c254ec022 100644
--- a/test/rubygems/test_gem_update_suggestion.rb
+++ b/test/rubygems/test_gem_update_suggestion.rb
@@ -15,13 +15,13 @@ class TestUpdateSuggestion < Gem::TestCase
@week = 7 * 24 * @minute
end
- def with_eglible_environment(**params)
- self.class.with_eglible_environment(**params) do
+ def with_eligible_environment(**params)
+ self.class.with_eligible_environment(**params) do
yield
end
end
- def self.with_eglible_environment(
+ def self.with_eligible_environment(
tty: true,
rubygems_version: Gem::Version.new("1.2.3"),
latest_rubygems_version: Gem::Version.new("2.0.0"),
@@ -65,10 +65,10 @@ class TestUpdateSuggestion < Gem::TestCase
end
end
- def test_eglible_for_update
- with_eglible_environment(cmd: @cmd) do
+ def test_eligible_for_update
+ with_eligible_environment(cmd: @cmd) do
Time.stub :now, 123_456_789 do
- assert_predicate @cmd, :eglible_for_update?
+ assert_predicate @cmd, :eligible_for_update?
assert_equal 123_456_789, Gem.configuration.last_update_check
# test last check is written to config file
@@ -77,29 +77,29 @@ class TestUpdateSuggestion < Gem::TestCase
end
end
- def test_eglible_for_update_is_not_annoying_when_new_version_is_released
+ def test_eligible_for_update_is_not_annoying_when_new_version_is_released
current_version = Gem::Version.new("1.2.0")
latest_version = current_version
# checking for first time, it is not eglible since new version
# is not released yet and stored
- with_eglible_environment(cmd: @cmd, rubygems_version: current_version, latest_rubygems_version: latest_version) do
+ with_eligible_environment(cmd: @cmd, rubygems_version: current_version, latest_rubygems_version: latest_version) do
Time.stub :now, @start_time do
- refute_predicate @cmd, :eglible_for_update?
+ refute_predicate @cmd, :eligible_for_update?
assert_equal @start_time, Gem.configuration.last_update_check
end
end
# checking next week, it is not eglible since new version
# is not released yet and timestamp is stored
- with_eglible_environment(
+ with_eligible_environment(
cmd: @cmd,
rubygems_version: current_version,
latest_rubygems_version: latest_version,
reset_last_update_check: false
) do
Time.stub :now, @start_time + @week do
- refute_predicate @cmd, :eglible_for_update?
+ refute_predicate @cmd, :eligible_for_update?
assert_equal @start_time + @week, Gem.configuration.last_update_check
end
end
@@ -107,103 +107,103 @@ class TestUpdateSuggestion < Gem::TestCase
# pretend new version is released
latest_version = Gem::Version.new("1.3.0")
# checking later same next week, it is not eglible even new version
# is released and timestamp is not stored
- with_eglible_environment(
+ with_eligible_environment(
cmd: @cmd,
rubygems_version: current_version,
latest_rubygems_version: latest_version,
reset_last_update_check: false
) do
Time.stub :now, @start_time + @week + @minute do
- refute_predicate @cmd, :eglible_for_update?
+ refute_predicate @cmd, :eligible_for_update?
assert_equal @start_time + @week, Gem.configuration.last_update_check
end
end
end
- def test_eglible_for_update_is_not_annoying_when_not_upgraded
- with_eglible_environment(cmd: @cmd) do
- # checking for first time, it is eglible and stored
+ def test_eligible_for_update_is_not_annoying_when_not_upgraded
+ with_eligible_environment(cmd: @cmd) do
+ # checking for first time, it is eligible and stored
Time.stub :now, @start_time do
- assert_predicate @cmd, :eglible_for_update?
+ assert_predicate @cmd, :eligible_for_update?
assert_equal @start_time, Gem.configuration.last_update_check
end
# checking minute later is not eglible and not stored
Time.stub :now, @start_time + @minute do
- refute_predicate @cmd, :eglible_for_update?
+ refute_predicate @cmd, :eligible_for_update?
assert_equal @start_time, Gem.configuration.last_update_check
end
# checking week later is eglible again and stored
Time.stub :now, @start_time + @week do
- assert_predicate @cmd, :eglible_for_update?
+ assert_predicate @cmd, :eligible_for_update?
assert_equal @start_time + @week, Gem.configuration.last_update_check
end
end
end
- def test_eglible_for_update_prevent_config
- with_eglible_environment(cmd: @cmd) do
+ def test_eligible_for_update_prevent_config
+ with_eligible_environment(cmd: @cmd) do
original_config = Gem.configuration[:prevent_update_suggestion]
Gem.configuration[:prevent_update_suggestion] = true
- refute_predicate @cmd, :eglible_for_update?
+ refute_predicate @cmd, :eligible_for_update?
ensure
Gem.configuration[:prevent_update_suggestion] = original_config
end
end
- def test_eglible_for_update_prevent_env
- with_eglible_environment(cmd: @cmd) do
+ def test_eligible_for_update_prevent_env
+ with_eligible_environment(cmd: @cmd) do
original_env = ENV["RUBYGEMS_PREVENT_UPDATE_SUGGESTION"]
ENV["RUBYGEMS_PREVENT_UPDATE_SUGGESTION"] = "yes"
- refute_predicate @cmd, :eglible_for_update?
+ refute_predicate @cmd, :eligible_for_update?
ensure
ENV["RUBYGEMS_PREVENT_UPDATE_SUGGESTION"] = original_env
end
end
- def test_eglible_for_update_non_tty
- with_eglible_environment(tty: false, cmd: @cmd) do
- refute_predicate @cmd, :eglible_for_update?
+ def test_eligible_for_update_non_tty
+ with_eligible_environment(tty: false, cmd: @cmd) do
+ refute_predicate @cmd, :eligible_for_update?
end
end
- def test_eglible_for_update_for_prerelease
- with_eglible_environment(rubygems_version: Gem::Version.new("1.0.0-rc1"), cmd: @cmd) do
- refute_predicate @cmd, :eglible_for_update?
+ def test_eligible_for_update_for_prerelease
+ with_eligible_environment(rubygems_version: Gem::Version.new("1.0.0-rc1"), cmd: @cmd) do
+ refute_predicate @cmd, :eligible_for_update?
end
end
- def test_eglible_for_update_disabled_update
- with_eglible_environment(cmd: @cmd) do
+ def test_eligible_for_update_disabled_update
+ with_eligible_environment(cmd: @cmd) do
original_disable = Gem.disable_system_update_message
Gem.disable_system_update_message = "disabled"
- refute_predicate @cmd, :eglible_for_update?
+ refute_predicate @cmd, :eligible_for_update?
ensure
Gem.disable_system_update_message = original_disable
end
end
- def test_eglible_for_update_on_ci
- with_eglible_environment(ci: true, cmd: @cmd) do
- refute_predicate @cmd, :eglible_for_update?
+ def test_eligible_for_update_on_ci
+ with_eligible_environment(ci: true, cmd: @cmd) do
+ refute_predicate @cmd, :eligible_for_update?
end
end
- def test_eglible_for_update_unwrittable_config
- with_eglible_environment(cmd: @cmd) do
+ def test_eligible_for_update_unwrittable_config
+ with_eligible_environment(cmd: @cmd) do
Gem.configuration.stub :state_file_writable?, false do
- refute_predicate @cmd, :eglible_for_update?
+ refute_predicate @cmd, :eligible_for_update?
end
end
end
- def test_eglible_for_update_notification_delay
- with_eglible_environment(cmd: @cmd) do
+ def test_eligible_for_update_notification_delay
+ with_eligible_environment(cmd: @cmd) do
Gem.configuration.last_update_check = Time.now.to_i
- refute_predicate @cmd, :eglible_for_update?
+ refute_predicate @cmd, :eligible_for_update?
end
end
end
@@ -77,29 +77,29 @@ class TestUpdateSuggestion < Gem::TestCase
current_version = Gem::Version.new("1.2.0")
latest_version = current_version
- # checking for first time, it is not eglible since new version
+ # checking for first time, it is not eligible since new version
# is not released yet and stored
@@ -77,29 +77,29 @@ class TestUpdateSuggestion < Gem::TestCase
end
end
- # checking next week, it is not eglible since new version
+ # checking next week, it is not eligible since new version
# is not released yet and timestamp is stored
@@ -107,103 +107,103 @@ class TestUpdateSuggestion < Gem::TestCase
# pretend new version is released
latest_version = Gem::Version.new("1.3.0")
- # checking later same next week, it is not eglible even new version
+ # checking later same next week, it is not eligible even new version
# is released and timestamp is not stored
@@ -107,103 +107,103 @@ class TestUpdateSuggestion < Gem::TestCase
assert_equal @start_time, Gem.configuration.last_update_check
end
- # checking minute later is not eglible and not stored
+ # checking minute later is not eligible and not stored
Time.stub :now, @start_time + @minute do
@@ -107,103 +107,103 @@ class TestUpdateSuggestion < Gem::TestCase
assert_equal @start_time, Gem.configuration.last_update_check
end
- # checking week later is eglible again and stored
+ # checking week later is eligible again and stored
Time.stub :now, @start_time + @week do